@@ -27,7 +27,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Henryhaoson"
     author_url = "https://git.17bdc.com/android-apps/sentry-dingtalk"
-    version = "2.0.7"
+    version = "4.0.0"
     resource_links = [
         ("Report Issue", "https://git.17bdc.com/android-apps/sentry-dingtalk/issues"),
         ("View Source", "https://git.17bdc.com/android-apps/sentry-dingtalk"),
@@ -101,6 +101,8 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
         webhook = self.get_option("webhook", project)
         webhook_optional = self.get_option("webhook_optional", project)
         ats_str = self.get_option("ats", project)
+        if ats_str == None:
+            ats_str = ""
         ats_array = ats_str.split(",")
         ats_ding_str = ""
         for at in ats_array:
